@@ -1,11 +1,11 @@
-try:
-    import pynotify as notify
-except ImportError:
-    import Growl as notify
-
 import sys
 import subprocess
 
+if sys.platform == 'linux2':
+    import pynotify as notify
+else:
+    import Growl as notify
+
 def display_notification(command, return_code):
     description = u'finished with return code %s' % return_code
 
